PALM-meteo: palmmeteo.library.UnitConverter Class Reference

PALM-meteo

Public Member Functions | Public Attributes | Static Public Attributes | List of all members
palmmeteo.library.UnitConverter Class Reference

## Public Member Functions
def | __init__ (self)
def | convert_auto (self, name, value, unit)
def | convert (cls, name, value, unit)

## Public Attributes
| re_ppmv
| re_ppbv
| re_ugm3
| re_gm3
| re_kgm3

## Static Public Attributes
| loaded = None

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo.library.UnitConverter.__init__ | ( |  | self | ) |

## Member Function Documentation

## ◆ convert()

def palmmeteo.library.UnitConverter.convert | ( |  | cls,
|  |  | name,
|  |  | value,
|  |  | unit
| ) |  |

## ◆ convert_auto()

def palmmeteo.library.UnitConverter.convert_auto | ( |  | self,
|  |  | name,
|  |  | value,
|  |  | unit
| ) |  |

## Member Data Documentation

## ◆ loaded

palmmeteo.library.UnitConverter.loaded = None
| static

## ◆ re_gm3

palmmeteo.library.UnitConverter.re_gm3

## ◆ re_kgm3

palmmeteo.library.UnitConverter.re_kgm3

## ◆ re_ppbv

palmmeteo.library.UnitConverter.re_ppbv

## ◆ re_ppmv

palmmeteo.library.UnitConverter.re_ppmv

## ◆ re_ugm3

palmmeteo.library.UnitConverter.re_ugm3

The documentation for this class was generated from the following file:

- palmmeteo/library.py